@@ -34,7 +34,7 @@ sample_info.data.frame <- function(x) {
 
   if (length(nnames) != 0) {
     suppressMessages(
-      x <- left_join(num, fac) %>% grouped_df(vars = lapply(nnames, as.name))
+      x <- left_join(num, fac) %>% group_by(!!!lapply(nnames, as.name))
     )
   } else {
     x <- bind_cols(num, fac)
@@ -81,7 +81,8 @@ sample_info.fped <- function(x) {
 #'
 #' Works like \code{\link[base]{expand.grid}} but for data frames.
 #'
-#' @importFrom dplyr slice bind_cols combine
+#' @importFrom dplyr slice bind_cols
+#' @importFrom vctrs vec_c
 #' @importFrom purrr map map_lgl map2 transpose cross
 #' @importFrom checkmate test_data_frame
 #' @param ... Data frames that should be combined to one data frame.
@@ -101,7 +102,7 @@ combine_df <- function(...) {
   }
   ind_seq   <- map(dots, ~ seq_len(nrow(.x)))
   not_empty <- map_lgl(ind_seq, ~ length(.x) > 0)
-  ind_list  <- ind_seq[not_empty] %>% cross() %>% transpose() %>% map(combine)
+  ind_list  <- ind_seq[not_empty] %>% cross() %>% transpose() %>% map(function(x) vec_c(!!!x))
 
   map2(dots[not_empty], ind_list, function(.x, .y) slice(.x, .y)) %>%
     bind_cols()
@@ -240,7 +241,7 @@ make_newdata.ped <- function(x, ...) {
     }
     ndf$tend <- int_tend
     suppressMessages(
-      ndf <- right_join(int_df, ndf)
+      ndf <- ndf %>% left_join(int_df)
       )
   } else {
     ndf <- combine_df(int_df[1, ], ndf)
@@ -281,7 +282,7 @@ make_newdata.fped <- function(x, ...) {
   out_df <- do.call(combine_df, compact(list(cumu_smry, ndf)))
   int_df <- int_info(attr(x, "breaks"))
   suppressMessages(
-    out_df <- right_join(int_df, out_df) %>%
+    out_df <- out_df %>% left_join(int_df) %>%
       select(-one_of(c("intmid"))) %>% as_tibble()
       )
 
