@@ -58,7 +58,7 @@ test_that("make_newdata works for PED data", {
 test_that("make_newdata works for PED with matrix columns", {
 
   ped_simdf <- simdf_elra %>% as_ped(
-    Surv(time, status)~ x1 + x2 +
+    Surv(time, status) ~ x1 + x2 +
       cumulative(time, latency(tz1), z.tz1, tz_var = "tz1",
         ll_fun = function(t, tz) t >= tz + 2) +
       cumulative(latency(tz2), z.tz2, tz_var = "tz2"),
@@ -97,7 +97,10 @@ test_that("make_newdata works for PED with matrix columns", {
   expect_data_frame(nd4, nrows = 6L, ncols = 16L)
   expect_equal(nd4$tz1_latency, 0:5)
 
-  nd5 <- ped_simdf %>% make_newdata(tend = c(1:10), tz1_latency = seq(1:5))
+  nd5 <- ped_simdf %>%
+    make_newdata(
+      tend = c(1:10),
+      tz1_latency = seq(1:5))
   expect_data_frame(nd5, nrows = 50L, ncols = 16L)
   expect_equal(nd5$tend, rep(1:10, 5L))
   expect_equal(nd5$tz1_latency, rep(1:5, each = 10L))
